#
# spec file for package apache2-mod_musicindex
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%bcond_with mad

%if %{defined suse_version}
BuildRequires:  apache2-devel
BuildRequires:  apache-rpm-macros
BuildRequires:  apache2-prefork
BuildRequires:  apache2-worker
%else
%define apache_apxs %{_sbindir}/apxs
BuildRequires:  httpd-devel
%endif
Name:           apache2-mod_musicindex
Version:        1.4.1
Release:        5.6
Summary:        Nice Displaying of Directories containing Music Files
License:        LGPL-2.1+
Group:          Productivity/Networking/Web/Servers
Url:            http://hacks.slashdirt.org/musicindex/
Source:         http://hacks.slashdirt.org/musicindex/mod_musicindex-%{version}.tar.gz
Patch1:         apache2-mod_musicindex-fix_printf_format.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  flac-devel
BuildRequires:  gcc
BuildRequires:  libarchive-devel
BuildRequires:  libid3tag-devel
BuildRequires:  libmysqlclient-devel
BuildRequires:  libogg-devel
BuildRequires:  libtool
BuildRequires:  libvorbis-devel
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{defined suse_version}
%if %{defined apache_mmn}
Requires:       %{apache_mmn}
%endif
%if %{defined apache_suse_maintenance_mmn}
Requires:       %{apache_suse_maintenance_mmn}
%endif
Requires:       apache2
%else
Requires:       httpd
%endif
%if %{with mad}
BuildRequires:  libmad-devel
Provides:       %{name}-with-mp3 = %{version}
Provides:       %{name}-with-mad = %{version}
%endif

%description
mod_musicindex is an Apache module aimed at being a C alternative to the Perl
module Apache::MP3. It allows nice displaying of directories containing MP3,
Ogg Vorbis, FLAC, or MP4/AAC files, including sorting them on various fields,
streaming/downloading them, constructing playlists, and searching. It also
provides features such as RSS and Podcast feeds, multiple CSS support, and
archive downloads.

%if %{without mad}
Note that this package is built *without* MP3/MP4 support, as it requires
libmad, which potentially infringes on software patents.
%endif

%prep
%setup -q -n "mod_musicindex-%{version}"
%patch1

%build
%configure \
    --with-apxs="%{apache_apxs}" \
    --disable-rpath \
2>&1|tee conf.rpm.log
r="${PIPESTATUS[0]}"
if [ "$r" != "0" ]; then
    echo "ERROR: configure failed" >&2
    exit $r
fi

for x in Vorbis FLAC \
%if %{with mad}
MP3 \
%endif
; do
    grep -q -E '^Building '"$x"' codec support: .*YES$' conf.rpm.log || {
        echo "ERROR: missing support for codec: $x" >&2
        exit 1
    }
done

%if %{without mad}
for x in MP3 MP4; do
    grep -q -E '^Building '"$x"' codec support: .*NO$' conf.rpm.log || {
        echo "ERROR: forbidden support for codec: $x" >&2
        exit 1
    }
done
%endif

for x in "flat file" mysql; do
    grep -q -E '^Building '"$x"' backend: .*YES$' conf.rpm.log || {
        echo "ERROR: missing support for backend: $x" >&2
        exit 1
    }
done
for x in archive; do
    grep -q -E '^Building '"$x"' output support: .*YES$' conf.rpm.log || {
        echo "ERROR: missing support for output: $x" >&2
        exit 1
    }
done

make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}

%find_lang mod_musicindex

%check
set +x
%apache_test_module_load -m musicindex
set -x

%files -f mod_musicindex.lang
%defattr(-,root,root)
%doc AUTHORS BUGS COPYING ChangeLog README
%doc README.Handlers TODO UPGRADING
%{apache_libexecdir}/mod_musicindex.so
%{_datadir}/mod_musicindex

%changelog
* Sun Mar 12 2017 olaf@aepfle.de
- Disable mp4 because libmp4v2 was dropped from packman
- Convert mad check to build conditional
- Wrap some apache macros to allow quilt setup if apache-devel is not installed
* Tue Sep  1 2015 pgajdos@suse.com
- test module with %%apache_test_module_load
* Thu Jul 16 2015 pgajdos@suse.com
- Requries: %%{apache_suse_maintenance_mmn}
  This will pull this module to the update (in released distribution)
  when apache maintainer thinks it is good (due api/abi changes).
* Mon Nov  3 2014 pgajdos@suse.com
- call spec-cleaner
- use apache rpm macros
* Tue Apr  9 2013 pascal.bleser@opensuse.org
- update to 1.4.1:
  * fixes a single bug introduced in 1.4.0 in which the tarball download was
    sending garbage
* Thu Oct 18 2012 pascal.bleser@opensuse.org
- update to 1.4.0:
  * makes the module compatible with Apache 2.4
  * implements a few cosmetic changes as well as RFC3803
  * fixes a fairly long list of minor bugs
  * improves the overall performance of the module (reducing memory and CPU
    usage)
* Thu Apr 12 2012 pascal.bleser@opensuse.org
- update to 1.3.7:
  * fixes an XHTML rendering error
  * fixes a cosmetic bug in the recursive search display
* Tue Nov  1 2011 pascal.bleser@opensuse.org
- initial version (1.3.6)
